@@ -38,9 +38,7 @@
 #' where \code{delta} and \code{weight} are based on \code{aic} for censored data
 #' and \code{aicc} for non-censored data.
 #'
-#' @param x The object.
-#' @param ... Unused.
-#'
+#' @inheritParams params
 #' @return A tbl data frame of the gof statistics.
 #' @export
 #' @examples
@@ -52,16 +50,20 @@ ssd_gof <- function(x, ...) {
 
 #' @describeIn ssd_gof Goodness of Fit
 #' @export
+#' @examples
+#' ssd_gof(boron_lnorm)
 ssd_gof.fitdist <- function(x, ...) {
+  chk_unused(...)
+
   dist <- x$distname
-  n <- stats::nobs(x)
+  n <- nobs(x)
   k <- npars(x)
 
   aic <- x$aic
-  aicc <- aic  + 2 * k * (k + 1) / (n - k - 1)
+  aicc <- aic + 2 * k * (k + 1) / (n - k - 1)
   bic <- x$bic
 
-  if(n >= 8) {
+  if (n >= 8) {
     x <- fitdistrplus::gofstat(x)
     ad <- x$ad
     ks <- x$ks
@@ -71,31 +73,61 @@ ssd_gof.fitdist <- function(x, ...) {
     ks <- NA_real_
     cvm <- NA_real_
   }
-  data <- data.frame(dist = dist, ad = ad, ks = ks, cvm = cvm,
-                    aic = aic, aicc = aicc, bic = bic, stringsAsFactors = FALSE)
-  as_conditional_tibble(data)
+  data <- data.frame(
+    dist = dist, ad = ad, ks = ks, cvm = cvm,
+    aic = aic, aicc = aicc, bic = bic, stringsAsFactors = FALSE
+  )
+  as_tibble(data)
 }
 
-#' @describeIn ssd_gof Goodness of Fit
-#' @export
-ssd_gof.fitdistcens <- function(x, ...) {
-  dist <- x$distname
-  data <- data.frame(dist = dist, aic = x$aic, bic = x$bic, 
-                     stringsAsFactors = FALSE)
-  as_conditional_tibble(data)
-}
-
-#' @describeIn ssd_gof Goodness of Fit
-#' @export
-ssd_gof.fitdists <- function(x, ...) {
+.ssd_gof_fitdists <- function(x) {
   x <- lapply(x, ssd_gof)
   x$stringsAsFactors <- FALSE
   x <- do.call("rbind", x)
-  if(!is.null(x$aicc)) {
+  if ("aicc" %in% colnames(x)) {
     x$delta <- x$aicc - min(x$aicc)
-  } else # aicc not defined for censored data
+  } else { # aicc not defined for censored data
     x$delta <- x$aic - min(x$aic)
-  x$weight <- exp(-x$delta/2)/sum(exp(-x$delta/2))
+  }
+  x$weight <- exp(-x$delta / 2) / sum(exp(-x$delta / 2))
+  x
+}
+
+#' @describeIn ssd_gof Goodness of Fit
+#' @export
+#' @examples
+#' ssd_gof(boron_dists)
+ssd_gof.fitdists <- function(x, ...) {
+  chk_unused(...)
+
+  x <- .ssd_gof_fitdists(x)
+  x$weight <- round(x$weight, 3)
+  x$delta <- round(x$delta, 3)
+  x
+}
+
+#' @describeIn ssd_gof Goodness of Fit
+#' @export
+#' @examples
+#' ssd_gof(fluazinam_lnorm)
+ssd_gof.fitdistcens <- function(x, ...) {
+  chk_unused(...)
+
+  data <- data.frame(
+    dist = x$distname, aic = x$aic, bic = x$bic,
+    stringsAsFactors = FALSE
+  )
+  as_tibble(data)
+}
+
+#' @describeIn ssd_gof Goodness of Fit
+#' @export
+#' @examples
+#' ssd_gof(fluazinam_lnorm)
+ssd_gof.fitdistscens <- function(x, ...) {
+  chk_unused(...)
+
+  x <- .ssd_gof_fitdists(x)
   x$weight <- round(x$weight, 3)
   x$delta <- round(x$delta, 3)
   x
