@@ -12,11 +12,9 @@
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
 
-context("lgumbel")
-
 test_that("dlgumbel", {
-  expect_equal(dlgumbel(exp(3), log(3), log(1)), 0.01831564, tolerance = 0.0000001)
-  expect_equal(dlgumbel(exp(4), log(3), log(1)), 0.004664011, tolerance = 0.0000001)
+  expect_equal(dlgumbel(exp(3), 3, 1), 0.01831564, tolerance = 0.0000001)
+  expect_equal(dlgumbel(exp(4), 3, 1), 0.004664011, tolerance = 0.0000001)
 })
 
 test_that("fit lgumbel", {
@@ -25,7 +23,18 @@ test_that("fit lgumbel", {
   expect_true(is.fitdist(dist))
   expect_equal(
     coef(dist),
-    c(llocation = 0.653681627422279, lscale = 0.208983173310441)
+    c(llocation = 1.92249767793641, lscale = 1.23235840307164)
+  )
+})
+
+test_that("fit lgumbel Mn LT", {
+  mn_lt <- ssdtools::test_data[ssdtools::test_data$Chemical == "Mn LT", ]
+
+  dist <- ssdtools:::ssd_fit_dist(mn_lt, dist = "lgumbel")
+  expect_true(is.fitdist(dist))
+  expect_equal(
+    coef(dist),
+    c(llocation = 7.31628089226769, lscale = 1.00893875176455)
   )
 })
 
@@ -36,8 +45,8 @@ test_that("fit lgumbel cis", {
   expect_equal(
     as.data.frame(ssd_hc(dist, ci = TRUE, nboot = 10)),
     structure(list(
-      percent = 5, est = 1.76898186161132, se = 0.370544140148798,
-      lcl = 1.23066000903158, ucl = 2.26731711889413, dist = "lgumbel"
+      percent = 5, est = 1.76891782851293, se = 0.370590354900628,
+      lcl = 1.2300542477102, ucl = 2.26678393125552, dist = "lgumbel"
     ), class = "data.frame", row.names = c(
       NA,
       -1L
@@ -47,8 +56,8 @@ test_that("fit lgumbel cis", {
   expect_equal(
     as.data.frame(ssd_hp(dist, conc = 2, ci = TRUE, nboot = 10)),
     structure(list(
-      conc = 2, est = 6.64205158066981, se = 3.00152144129526,
-      lcl = 3.43280320738647, ucl = 12.0632543930362, dist = "lgumbel"
+      conc = 2, est = 6.6426765222485, se = 3.00359276728387,
+      lcl = 3.43548429065931, ucl = 12.0724651584046, dist = "lgumbel"
     ), class = "data.frame", row.names = c(
       NA,
       -1L
@@ -57,8 +66,8 @@ test_that("fit lgumbel cis", {
 })
 
 test_that("pqlgumbel", {
-  expect_equal(log(qlgumbel(c(0.2, 0.5, 0.9), log(3), log(1))), c(2.52411500467289, 3.36651292058166, 5.25036732731245))
-  expect_equal(log(qlgumbel(c(0.2, 0.5, 0.9), log(3), log(1),
+  expect_equal(log(qlgumbel(c(0.2, 0.5, 0.9), 3, 1)), c(2.52411500467289, 3.36651292058166, 5.25036732731245))
+  expect_equal(log(qlgumbel(c(0.2, 0.5, 0.9), 3, 1,
     lower.tail = FALSE
   )), c(4.49993998675952, 3.36651292058166, 2.16596755475204))
 
@@ -67,14 +76,14 @@ test_that("pqlgumbel", {
     log(qlgumbel(exp(-1)))
   )
 
-  expect_equal(plgumbel(exp(3), log(3), log(1)), 0.3678794, tolerance = 0.0000001)
-  expect_equal(plgumbel(exp(4), log(3), log(1)), 0.6922006, tolerance = 0.0000001)
+  expect_equal(plgumbel(exp(3), 3, 1), 0.3678794, tolerance = 0.0000001)
+  expect_equal(plgumbel(exp(4), 3, 1), 0.6922006, tolerance = 0.0000001)
   expect_identical(plgumbel(qlgumbel(0.5, 3, 1), 3, 1), 0.5)
 })
 
 test_that("rlgumbel", {
   set.seed(99)
-  r <- rlgumbel(100000, llocation = log(100), lscale = log(3))
+  r <- rlgumbel(100000, llocation = 100, lscale = 3)
   expect_identical(length(r), 100000L)
   expect_equal(mean(log(r)), 3 * 0.57721 + 100, tolerance = 0.001)
 })
